@@ -129,7 +129,7 @@ pref("calendar.threading.latency ", 250);
 pref("calendar.network.multirealm", false);
 
 // Set up user agent
-pref("calendar.useragent.extra", "Lightning/3.3");
+pref("calendar.useragent.extra", "Lightning/4.0.1");
 
 // Disable use of system colors in minimonth and calendar views
 pref("calendar.view.useSystemColors", false);
@@ -140,3 +140,6 @@ pref("calendar.filter.maxiterations", 50);
 
 // Backend to use. false: libical, true: ical.js
 pref("calendar.icaljs", false);
+
+// Calendar integration notification
+pref("calendar.integration.notify", true);
